@@ -3,16 +3,16 @@
 # Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -201,9 +201,10 @@ def printDetails(level, indent, accessible, includeApp=True):
     """
 
     if level >= debugLevel and accessible:
-        println(level, getAccessibleDetails(accessible, indent, includeApp))
+        println(level,
+                getAccessibleDetails(level, accessible, indent, includeApp))
 
-def getAccessibleDetails(acc, indent="", includeApp=True):
+def getAccessibleDetails(level, acc, indent="", includeApp=True):
     """Returns a string, suitable for printing, that describes the
     given accessible.
 
@@ -213,6 +214,9 @@ def getAccessibleDetails(acc, indent="", includeApp=True):
                   for this accessible.
     """
 
+    if level < debugLevel:
+        return ""
+
     if includeApp:
         app = acc.getApplication()
         if app:
@@ -223,15 +227,24 @@ def getAccessibleDetails(acc, indent="", includeApp=True):
         string = indent
 
     # create the States string
-    stateSet = acc.getState()
-    states = stateSet.getStates()
+    try:
+        stateSet = acc.getState()
+    except:
+        string += "(exception getting state set)"
+    try:
+        states = stateSet.getStates()
+    except:
+        string += "(exception getting states)"
     state_strings = []
     for state in states:
         state_strings.append(pyatspi.stateToString(state))
     state_string = ' '.join(state_strings)
 
     # create the relations string
-    relations = acc.getRelationSet()
+    try:
+        relations = acc.getRelationSet()
+    except:
+        string += "(exception getting relation set)"
     if relations:
         relation_strings = []
         for relation in relations:
@@ -245,7 +258,7 @@ def getAccessibleDetails(acc, indent="", includeApp=True):
         string += "name='%s' role='%s' state='%s' relations='%s'" \
                   % (acc.name or 'None', acc.getRoleName(),
                      state_string, rel_string)
-    except DataError:
+    except:
         string += "(exception fetching data)"
 
     return string
