@@ -3,16 +3,16 @@
 # Copyright 2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -219,12 +219,13 @@ class Generator:
             else:
                 firstTimeCalled = False
 
+            details = debug.getAccessibleDetails(debug.LEVEL_ALL, obj)
             debug.println(
                 debug.LEVEL_ALL,
                 "\n\n\ngenerate %s for %s %s (args=%s) using '%s'" \
                 % (self._mode,
                    args['formatType'], 
-                   debug.getAccessibleDetails(obj),
+                   details,
                    repr(args),
                    format))
 
@@ -879,11 +880,13 @@ class Generator:
 
     def _generateDisplayedText(self, obj, **args ):
         """Returns an array of strings for use by speech and braille that
-        represents all the text being displayed by the object. [[[WDW
-        - consider returning an empty array if this is not a text
-        object.]]]
+        represents all the text being displayed by the object.
         """
-        return [self._script.utilities.displayedText(obj)]
+        displayedText = self._script.utilities.displayedText(obj)
+        if not displayedText:
+            return []
+
+        return [displayedText]
 
     #####################################################################
     #                                                                   #
