@@ -108,9 +108,8 @@ class Script(default.Script):
         - event: the Event
         """
 
-        debug.printObjectEvent(self.debugLevel,
-                               event,
-                               debug.getAccessibleDetails(event.source))
+        details = debug.getAccessibleDetails(self.debugLevel, event.source)
+        debug.printObjectEvent(self.debugLevel, event, details)
 
         # self.printAncestry(event.source)
 
