@@ -3,16 +3,16 @@
 # Author: Tomas Cerha <cerha@brailcom.org>
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -190,6 +190,7 @@ class SpeechServer(speechserver.SpeechServer):
 
     def _init(self):
         self._client = client = speechd.SSIPClient('Orca', component=self._id)
+        client.set_priority(speechd.Priority.MESSAGE)
         if self._id != self.DEFAULT_SERVER_ID:
             client.set_output_module(self._id)
         self._current_voice_properties = {}
@@ -310,6 +311,8 @@ class SpeechServer(speechserver.SpeechServer):
         return newText.encode("UTF-8")
 
     def _speak(self, text, acss, **kwargs):
+        if isinstance(text, ACSS):
+            text = ''
         text = self.__addVerbalizedPunctuation(text)
         # Replace no break space characters with plain spaces since some
         # synthesizers cannot handle them.  See bug #591734.
